@@ -7,6 +7,7 @@ require('./pkgtree.js')(pkg, {
   $package: {
     name: 'a',
     version: '1.2.3',
+    bundledDependencies: false,
     dependencies: {
       b: '1.2.3',
       d: '1.2.3'
@@ -16,6 +17,7 @@ require('./pkgtree.js')(pkg, {
     d: { $package: {
       name: 'd',
       version: '1.2.3',
+      bundleDependencies: false,
       dependencies: {
         e: '1.2.3'
       }
